@@ -2,16 +2,17 @@ from django.test import TestCase
 from django.test.client import RequestFactory
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.auth.models import User
+
 from mqueue.models import MEvent
 
 
 class MqueueBaseTest(TestCase):
-    user = None
+    user: User
 
     def setUp(self):
         self.factory = RequestFactory()
         self.maxDiff = None
-        self.user = User.objects.create_user(
+        self.user = User.objects.create_user(  # type: ignore
             "myuser", "myemail@test.com", "super_password"
         )
 
@@ -19,7 +20,13 @@ class MqueueBaseTest(TestCase):
         for event in MEvent.objects.all():
             event.delete()
 
-    def create_mevent(self, name="M event", url="/", obj_pk=1, notes="Notes"):
+    def create_mevent(
+        self,
+        name: str = "M event",
+        url: str = "/",
+        obj_pk: int = 1,
+        notes: str = "Notes",
+    ):
         self._content_type = ContentType.objects.get_for_model(User)
         return MEvent.objects.create(
             name=name,
